@@ -4,7 +4,7 @@ use strict;
 require Exporter;
 use vars qw/$VERSION @ISA @EXPORT @EXPORT_OK $DEBUG/;
 
-$VERSION    = '0.48'; # Change version in POD, too!
+$VERSION    = '0.50';
 @ISA        = 'Exporter';
 @EXPORT     = qw/
   blib_to_par
@@ -32,10 +32,6 @@ use File::Spec;
 
 PAR::Dist - Create and manipulate PAR distributions
 
-=head1 VERSION
-
-This document describes version 0.47 of PAR::Dist, released November 29, 2009.
-
 =head1 SYNOPSIS
 
 As a shell command:
@@ -61,7 +57,7 @@ In programs:
 This module creates and manipulates I<PAR distributions>.  They are
 architecture-specific B<PAR> files, containing everything under F<blib/>
 of CPAN distributions after their C<make> or C<Build> stage, a
-F<META.yml> describing metadata of the original CPAN distribution, 
+F<META.yml> describing metadata of the original CPAN distribution,
 and a F<MANIFEST> detailing all files within it.  Digitally signed PAR
 distributions will also contain a F<SIGNATURE> file.
 
@@ -168,7 +164,7 @@ sub blib_to_par {
     my @files;
     open MANIFEST, ">", File::Spec->catfile("blib", "MANIFEST") or die $!;
     open META, ">", File::Spec->catfile("blib", "META.yml") or die $!;
-    
+
     require File::Find;
     File::Find::find( sub {
         next unless $File::Find::name;
@@ -214,7 +210,7 @@ sub blib_to_par {
         close OLD_META;
         close META;
     }
-    
+
     if ((!$name or !$version) and open(MAKEFILE, "Makefile")) {
         while (<MAKEFILE>) {
             if (/^DISTNAME\s+=\s+(.*)$/) {
@@ -236,11 +232,11 @@ sub blib_to_par {
         elsif (not defined $version) {
             $what = 'version';
         }
-        
+
         carp("I was unable to determine the $what of the PAR distribution. Please create a Makefile or META.yml file from which we can infer the information or just specify the missing information as an option to blib_to_par.");
         return();
     }
-    
+
     $name =~ s/\s+$//;
     $version =~ s/\s+$//;
 
@@ -435,7 +431,7 @@ sub _install_or_uninstall {
 
     require Cwd;
     my $old_dir = Cwd::cwd();
-    
+
     my ($dist, $tmpdir) = _unzip_to_tmpdir( dist => $args{dist}, subdir => 'blib' );
 
     if ( open (META, File::Spec->catfile('blib', 'META.yml')) ) {
@@ -465,7 +461,7 @@ sub _install_or_uninstall {
         my $target = _installation_target( File::Spec->curdir, $name, \%args );
         my $custom_targets = $args{custom_targets} || {};
         $target->{$_} = $custom_targets->{$_} foreach keys %{$custom_targets};
-        
+
         my $uninstall_shadows = $args{uninstall_shadows};
         my $verbose = $args{verbose};
         ExtUtils::Install::install($target, $verbose, 0, $uninstall_shadows);
@@ -529,7 +525,7 @@ sub _installation_target {
        $sources{inst_man1dir}   => $Config::Config{installman1dir},
        $sources{inst_man3dir}   => $Config::Config{installman3dir},
     };
-    
+
     # Included for future support for ${flavour}perl external lib installation
 #    if ($Config::Config{flavour_perl}) {
 #        my $ext = File::Spec->catdir($dir, 'blib', 'ext');
@@ -543,7 +539,7 @@ sub _installation_target {
 #        $target->{ $sources{inst_external_include} } = $Config::Config{flavour_install_include};
 #        $target->{ $sources{inst_external_src} }     = $Config::Config{flavour_install_src};
 #    }
-    
+
     # insert user overrides
     foreach my $key (keys %$user) {
         my $value = $user->{$key};
@@ -647,7 +643,7 @@ sub merge_par {
     if (not -f $base_par or not -r _ or not -w _) {
         croak "'$base_par' is not a file or you do not have enough permissions to read and modify it.";
     }
-    
+
     foreach (@additional_pars) {
         if (not -f $_ or not -r _) {
             croak "'$_' is not a file or you do not have enough permissions to read it.";
@@ -656,7 +652,7 @@ sub merge_par {
 
     # The unzipping will change directories. Remember old dir.
     my $old_cwd = Cwd::cwd();
-    
+
     # Unzip the base par to a temp. dir.
     (undef, my $base_dir) = _unzip_to_tmpdir(
         dist => $base_par, subdir => 'blib'
@@ -672,7 +668,7 @@ sub merge_par {
     # delete (incorrect) MANIFEST
     unlink File::Spec->catfile($blibdir, 'MANIFEST');
 
-    # extract additional pars and merge    
+    # extract additional pars and merge
     foreach my $par (@additional_pars) {
         # restore original directory because the par path
         # might have been relative!
@@ -701,7 +697,7 @@ sub merge_par {
         );
         my ($vol, $subdir, undef) = File::Spec->splitpath( $add_dir, 1);
         my @dir = File::Spec->splitdir( $subdir );
-    
+
         # merge directory structure
         foreach my $dir (@dirs) {
             my ($v, $d, undef) = File::Spec->splitpath( $dir, 1 );
@@ -722,21 +718,21 @@ sub merge_par {
             );
             File::Copy::copy($file, $target)
               or die "Could not copy '$file' to '$target': $!";
-            
+
         }
         chdir($old_cwd);
         File::Path::rmtree([$add_dir]);
     }
-    
+
     # delete (copied) MANIFEST and META.yml
     unlink File::Spec->catfile($blibdir, 'MANIFEST');
     unlink File::Spec->catfile($blibdir, 'META.yml');
-    
+
     chdir($base_dir);
     my $resulting_par_file = Cwd::abs_path(blib_to_par(quiet => 1));
     chdir($old_cwd);
     File::Copy::move($resulting_par_file, $base_par);
-    
+
     File::Path::rmtree([$base_dir]);
 }
 
@@ -763,7 +759,7 @@ sub _merge_meta {
 
   _merge_provides($orig_tree, $extra_tree);
   _merge_requires($orig_tree, $extra_tree);
-  
+
   $yaml_functions->{DumpFile}->($meta_orig_file, $orig_meta);
 
   return 1;
@@ -798,7 +794,7 @@ sub _merge_requires {
   foreach my $type (qw(requires build_requires configure_requires recommends)) {
     next if not exists $extra_hash->{$type};
     $orig_hash->{$type} ||= {};
-    
+
     # one level clone is enough wrt META spec 1.4
     foreach my $module (keys %{ $extra_hash->{$type} }) {
       # FIXME there should be a version comparison here, BUT how are we going to do that without a guaranteed version.pm?
@@ -836,10 +832,10 @@ sub remove_man {
     if (not -f $par or not -r _ or not -w _) {
         croak "'$par' is not a file or you do not have enough permissions to read and modify it.";
     }
-    
+
     # The unzipping will change directories. Remember old dir.
     my $old_cwd = Cwd::cwd();
-    
+
     # Unzip the base par to a temp. dir.
     (undef, my $base_dir) = _unzip_to_tmpdir(
         dist => $par, subdir => 'blib'
@@ -860,14 +856,14 @@ sub remove_man {
                map  { File::Spec->catfile('blib', $_) }
                readdir DIRECTORY;
     close DIRECTORY;
-    
+
     File::Path::rmtree(\@dirs);
-    
+
     chdir($base_dir);
     my $resulting_par_file = Cwd::abs_path(blib_to_par());
     chdir($old_cwd);
     File::Copy::move($resulting_par_file, $par);
-    
+
     File::Path::rmtree([$base_dir]);
 }
 
@@ -895,7 +891,7 @@ sub get_meta {
 
     # The unzipping will change directories. Remember old dir.
     my $old_cwd = Cwd::cwd();
-    
+
     # Unzip the base par to a temp. dir.
     (undef, my $base_dir) = _unzip_to_tmpdir(
         dist => $dist, subdir => 'blib'
@@ -907,18 +903,18 @@ sub get_meta {
     if (not -r $meta) {
         return undef;
     }
-    
+
     open FH, '<', $meta
       or die "Could not open file '$meta' for reading: $!";
-    
+
     local $/ = undef;
     my $meta_text = <FH>;
     close FH;
-    
+
     chdir($old_cwd);
-    
+
     File::Path::rmtree([$base_dir]);
-    
+
     return $meta_text;
 }
 
@@ -1095,13 +1091,16 @@ sub _unzip_to_tmpdir {
     my %args = &_args;
 
     require File::Temp;
+    require Cwd;
 
     my $dist   = File::Spec->rel2abs($args{dist});
     my $tmpdirname = File::Spec->catdir(File::Spec->tmpdir, "parXXXXX");
-    my $tmpdir = File::Temp::mkdtemp($tmpdirname)        
+    my $tmpdir = File::Temp::mkdtemp($tmpdirname)
       or die "Could not create temporary directory from template '$tmpdirname': $!";
     my $path = $tmpdir;
     $path = File::Spec->catdir($tmpdir, $args{subdir}) if defined $args{subdir};
+    $path = Cwd::realpath($path);  #  symlinks cause Archive::Zip issues on some systems
+
     _unzip(dist => $dist, path => $path);
 
     chdir $tmpdir;
@@ -1139,7 +1138,7 @@ sub parse_dist_name {
     return(undef, undef, undef, undef) if not defined $file;
 
     (undef, undef, $file) = File::Spec->splitpath($file);
-    
+
     my $version = qr/v?(?:\d+(?:_\d+)?|\d*(?:\.\d+(?:_\d+)?)+)/;
     $file =~ s/\.(?:par|tar\.gz|tar)$//i;
     my @elem = split /-/, $file;
@@ -1158,7 +1157,7 @@ sub parse_dist_name {
         }
         push @dn, $e;
     }
-    
+
     my $dn;
     $dn = join('-', @dn) if @dn;
 
@@ -1168,7 +1167,7 @@ sub parse_dist_name {
 
     while (@elem) {
         my $e = shift @elem;
-        if ($e =~ /^$version|any_version$/) {
+        if ($e =~ /^(?:$version|any_version)$/) {
             $pv = $e;
             last;
         }
@@ -1199,7 +1198,7 @@ Example:
 
   use PAR::Dist;
   use File::Copy 'copy';
-  
+
   generate_blib_stub(
     name => 'MyApp', version => '1.00'
   );
@@ -1214,20 +1213,20 @@ sub generate_blib_stub {
     my %args = &_args;
     my $dist = $args{dist};
     require Config;
-    
+
     my $name    = $args{name};
     my $version = $args{version};
     my $suffix  = $args{suffix};
 
     my ($parse_name, $parse_version, $archname, $perlversion)
       = parse_dist_name($dist);
-    
+
     $name ||= $parse_name;
     $version ||= $parse_version;
     $suffix = "$archname-$perlversion"
       if (not defined $suffix or $suffix eq '')
          and $archname and $perlversion;
-    
+
     $suffix ||= "$Config::Config{archname}-$Config::Config{version}";
     if ( grep { not defined $_ } ($name, $version, $suffix) ) {
         warn "Could not determine distribution meta information from distribution name '$dist'";
@@ -1288,7 +1287,7 @@ sub contains_binaries {
 
     # The unzipping will change directories. Remember old dir.
     my $old_cwd = Cwd::cwd();
-    
+
     # Unzip the base par to a temp. dir.
     (undef, my $base_dir) = _unzip_to_tmpdir(
         dist => $dist, subdir => 'blib'
@@ -1306,9 +1305,9 @@ sub contains_binaries {
     );
 
     chdir($old_cwd);
-    
+
     File::Path::rmtree([$base_dir]);
-    
+
     return $found ? 1 : 0;
 }
 
